@@ -317,7 +317,7 @@ pub(crate) fn analyze(item_ast: &mut Item) -> QtyDef {
         let ref_unit_def = ref_unit_def_from_attr(&ref_unit_attr);
         qty_def.ref_unit_ident = Some(ref_unit_def.unit_ident.clone());
         qty_def.units = unit_defs_with_scale_from_attrs(&unit_attrs);
-        qty_def.units.push(ref_unit_def);
+        qty_def.units.insert(0, ref_unit_def);
         qty_def.units.sort_by(|a, b| {
             let x = opt_lit_to_f64(&a.scale);
             let y = opt_lit_to_f64(&b.scale);
@@ -581,6 +581,7 @@ fn codegen_qty_without_ref_unit(
     let unit_doc = format!("Unit of quantity `{}`.", qty_ident);
     let code_impl_quantity = codegen_impl_quantity(qty_ident, unit_enum_ident);
     quote!(
+        #code_impl_quantity
         #[doc = #unit_doc]
         #[derive(Copy, Clone, Debug, Eq, PartialEq)]
         pub enum #unit_enum_ident { #code_unit_variants }
@@ -596,7 +597,6 @@ fn codegen_qty_without_ref_unit(
             fn si_prefix(&self) -> Option<SIPrefix> { None }
             fn scale(&self) -> Option<AmountT> { None }
         }
-        #code_impl_quantity
     )
 }
 
@@ -669,6 +669,7 @@ fn codegen_qty_with_ref_unit(
     let unit_doc = format!("Unit of quantity `{}`.", qty_ident);
     let code_impl_quantity = codegen_impl_quantity(qty_ident, unit_enum_ident);
     quote!(
+        #code_impl_quantity
         #[doc = #unit_doc]
         #[derive(Copy, Clone, Debug, Eq, PartialEq)]
         pub enum #unit_enum_ident {
@@ -687,7 +688,6 @@ fn codegen_qty_with_ref_unit(
             #code_fn_si_prefix
             #code_fn_scale
         }
-        #code_impl_quantity
         impl HasRefUnit for #qty_ident {
             const REF_UNIT: #unit_enum_ident =
                 #unit_enum_ident::#ref_unit_ident;
